@@ -133,7 +133,7 @@ double Arrow::Distance (double x, double y, Item **item) const
 	return fabs (yy);
 }
 
-void Arrow::Draw (cairo_t *cr, bool is_vector) const
+void Arrow::Draw (cairo_t *cr, G_GNUC_UNUSED bool is_vector) const
 {
 	double theta = atan2 (m_yend - m_ystart, m_xend -m_xstart),
 		   length = sqrt ((m_yend - m_ystart) * (m_yend - m_ystart) + (m_xend -m_xstart) * (m_xend -m_xstart));
@@ -145,7 +145,7 @@ void Arrow::Draw (cairo_t *cr, bool is_vector) const
 		cairo_move_to (cr, ((m_StartHead == ArrowHeadNone)? 0.: m_A), 0.);
 		cairo_line_to (cr, ((m_EndHead == ArrowHeadNone)? length: length - m_A), 0.);
 		cairo_set_line_width (cr, GetLineWidth ());
-		cairo_set_source_rgba (cr, DOUBLE_RGBA_R (color), DOUBLE_RGBA_G (color), DOUBLE_RGBA_B (color), DOUBLE_RGBA_A (color));
+		cairo_set_source_rgba (cr,  GO_COLOR_TO_CAIRO (color));
 		cairo_stroke (cr);
 		cairo_set_line_width (cr, 0.);
 		switch (m_StartHead) {
@@ -239,6 +239,7 @@ void Arrow::UpdateBounds ()
 	m_y1 += m_C;
 	m_x0 -= m_C;
 	m_x1 += m_C;
+	Item::UpdateBounds ();
 }
 
 }
