@@ -522,11 +522,9 @@ void Fragment::UpdateItem ()
 void Fragment::SetSelected (int state)
 {
 	GOColor color, othercolor = 0;
-	bool visible = true;
 	switch (state) {	
 	case SelStateUnselected:
 		color = GO_COLOR_BLACK;
-		visible = false;
 		break;
 	case SelStateSelected:
 		color = SelectColor;
@@ -1364,7 +1362,7 @@ bool Fragment::Validate ()
 			}
 			unsigned length = (*it)->GetEndIndex () - (*it)->GetStartIndex () - (err - charge);
 			if ((*err == '+' && length == 1) ||
-			    (!strcmp (err, "−") && length == strlen ("−")))
+			    (!strncmp (err, "−", strlen ("−")) && length == strlen ("−")))
 				continue;
 			// if we are there, we have an error
 			Document *pDoc = dynamic_cast<Document*> (GetDocument ());
