@@ -4,7 +4,7 @@
  * GChemPaint library
  * mesomery.h 
  *
- * Copyright (C) 2002-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -107,6 +107,11 @@ Aligns the children.
 */
 	double GetYAlign ();
 
+/*!
+@return the localized object generic name.
+*/
+	std::string Name ();
+
 private:
 	Mesomery (gcu::Object* parent, Mesomer *mesomer);
 };
