@@ -2,7 +2,7 @@
  * Gnome Chemistry Utils
  * cmd-context.h 
  *
- * Copyright (C) 2007-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2007-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -23,8 +23,7 @@
 #ifndef GCU_CMD_CONTEXT_H
 #define GCU_CMD_CONTEXT_H
 
-#include <goffice/app/go-cmd-context-impl.h>
-#include <glib-object.h>
+#include <goffice/goffice.h>
 
 G_BEGIN_DECLS
 
@@ -37,7 +36,7 @@ charts.
 /*!
 @return the GType associated to GcuCmdContext.
 */
-#define GCU_CMD_CONTEXT_TYPE		(gcu_cmd_context_get_type ())
+#define GCU_TYPE_CMD_CONTEXT		(gcu_cmd_context_get_type ())
 GType		gcu_cmd_context_get_type   (void);
 
 /*!
