@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * gcu/glview.cc 
  *
- * Copyright (C) 2006-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2006-2009 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -27,12 +27,9 @@
 #include <gcu/gldocument.h>
 #include <gcu/glview.h>
 #include <gcu/macros.h>
-#include <goffice/goffice-features.h>
-#include <goffice/utils/go-image.h>
 #include <GL/gl.h>
 #include <GL/glu.h>
 #include <gtk/gtkgl.h>
-#include <gio/gio.h>
 #include <glib/gi18n-lib.h>
 #include <cmath>
 #include <cstring>
@@ -49,8 +46,6 @@ using namespace std;
 
 namespace gcu
 {
-GOConfNode *GLView::m_ConfNode = NULL;
-guint GLView::m_NotificationId = 0;
 int GLView::nbViews = 0;
 
 // Callbacks
@@ -60,9 +55,9 @@ static bool on_init(G_GNUC_UNUSED GtkWidget *widget, GLView* View)
 	return true;
 }
 
-bool on_reshape(G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED GdkEventConfigure *event, GLView* View) 
+bool on_reshape(G_GNUC_UNUSED GtkWidget *widget, GdkEventConfigure *event, GLView* View) 
 {
-	View->Reshape ();
+	View->Reshape (event->width, event->height);
 	return true;
 }
 
@@ -86,12 +81,6 @@ static bool on_pressed(G_GNUC_UNUSED GtkWidget *widget, GdkEventButton *event, G
 	return View->OnPressed (event);
 }
 
-static void on_config_changed (GOConfNode *node, gchar const *key, G_GNUC_UNUSED gpointer data)
-{
-	if (!strcmp (key, ROOTDIR"off-screen-rendering"))
-		OffScreenRendering = go_conf_get_bool (node, key);
-}
-
 // GLView implementation
 #define GCU_CONF_DIR_GL "gl"
 
@@ -119,9 +108,6 @@ GLView::GLView (GLDocument* pDoc) throw (std::runtime_error): Printable ()
 											GDK_GL_MODE_DOUBLE));
 		if (glconfig == NULL)
 			throw  runtime_error ("*** Cannot find the double-buffered visual.\n");
-		m_ConfNode = go_conf_get_node (Application::GetConfDir (), GCU_CONF_DIR_GL);
-		GCU_GCONF_GET_NO_CHECK ("off-screen-rendering", bool, OffScreenRendering, true)
-		m_NotificationId = go_conf_add_monitor (m_ConfNode, "off-screen-rendering", (GOConfMonitorFunc) on_config_changed, NULL);
 	}
 	/* create new OpenGL widget */
 	m_pWidget = GTK_WIDGET(gtk_drawing_area_new());
@@ -134,10 +120,11 @@ GLView::GLView (GLDocument* pDoc) throw (std::runtime_error): Printable ()
 					GDK_GL_RGBA_TYPE);
 	
 	gtk_widget_set_events(GTK_WIDGET(m_pWidget),
-	GDK_EXPOSURE_MASK|
-	GDK_BUTTON_MOTION_MASK|
-	GDK_POINTER_MOTION_HINT_MASK|
-	GDK_BUTTON_PRESS_MASK);
+		GDK_EXPOSURE_MASK |
+		GDK_POINTER_MOTION_MASK |
+		GDK_POINTER_MOTION_HINT_MASK |
+		GDK_BUTTON_PRESS_MASK |
+	    GDK_BUTTON_RELEASE_MASK);
 	
 	// Connect signal handlers
 	// Do initialization when widget has been realized.
@@ -163,10 +150,8 @@ GLView::~GLView ()
 {
 	nbViews--;
 	if (!nbViews) {
-		go_conf_remove_monitor (m_NotificationId);
-		go_conf_free_node (m_ConfNode);
-		m_ConfNode = NULL;
-		m_NotificationId = 0;
+		g_object_unref (glconfig);
+		glconfig = NULL;
 	}
 }
 
@@ -193,16 +178,18 @@ void GLView::Init ()
     }
 }
 
-void GLView::Reshape ()
+void GLView::Reshape (int width, int height)
 {
+	m_WindowWidth = width;
+	m_WindowHeight = height;
 	if (!m_bInit)
 		return;
 	float fAspect;
 	GdkGLContext *glcontext = gtk_widget_get_gl_context (m_pWidget);
 	GdkGLDrawable *gldrawable = gtk_widget_get_gl_drawable (m_pWidget);
 	if (gdk_gl_drawable_gl_begin (gldrawable, glcontext)) {
-		if (m_pWidget->allocation.height) {
-			fAspect = (GLfloat) m_pWidget->allocation.width / (GLfloat) m_pWidget->allocation.height;
+		if (height) {
+			fAspect = (GLfloat) width / (GLfloat) height;
 			if (fAspect == 0.0)
 				fAspect = 1.0;
 		} else	// don't divide by zero, not that we should ever run into that...
@@ -210,7 +197,7 @@ void GLView::Reshape ()
 		double x = m_Doc->GetMaxDist ();
 		if (x == 0)
 			x = 1;
-		glViewport (0,0, m_pWidget->allocation.width, m_pWidget->allocation.height);
+		glViewport (0,0, width, height);
 		if (fAspect > 1.0) {
 			m_Height = x * (1 - tan (m_Angle / 360 * M_PI));
 			m_Width = m_Height * fAspect;
@@ -264,7 +251,7 @@ void GLView::Update()
 		m_Doc->Draw (m_Euler);
 		gdk_gl_drawable_gl_end (gldrawable);
     }
-	Reshape ();
+	Reshape (m_WindowWidth, m_WindowHeight);
 	Draw ();
 }
 
@@ -307,7 +294,7 @@ bool GLView::OnMotion(GdkEventMotion *event)
 		Rotate (x - m_Lastx, y - m_Lasty);
 		m_Lastx = x;
 		m_Lasty = y;
-		gtk_widget_queue_draw_area(m_pWidget, 0, 0, m_pWidget->allocation.width, m_pWidget->allocation.height);
+		gtk_widget_queue_draw_area(m_pWidget, 0, 0, m_WindowWidth, m_WindowHeight);
 	}
 	return true;
 }
@@ -380,7 +367,7 @@ GdkPixbuf *GLView::BuildPixbuf (unsigned width, unsigned height) const
 		drawable = gdk_pixmap_get_gl_drawable (pixmap);
 		context = gdk_gl_context_new (drawable,
 						     NULL,
-						     TRUE,
+						     false,
 						     GDK_GL_RGBA_TYPE);
 	}
 	double aspect = (GLfloat) width / height;
@@ -396,7 +383,7 @@ GdkPixbuf *GLView::BuildPixbuf (unsigned width, unsigned height) const
 	}
 	GdkPixbuf *pixbuf = NULL;
 	gdk_error_trap_push ();
-	bool result = OffScreenRendering && gl_pixmap && gdk_gl_drawable_gl_begin (drawable, context);
+	bool result = gl_pixmap && gdk_gl_drawable_gl_begin (drawable, context);
 	gdk_flush ();
 	if (gdk_error_trap_pop ())
 		result = false;
@@ -446,14 +433,14 @@ GdkPixbuf *GLView::BuildPixbuf (unsigned width, unsigned height) const
 		gtk_window_present (GTK_WINDOW (gtk_widget_get_toplevel (m_pWidget))); 
 		while (gtk_events_pending ())
 			gtk_main_iteration ();
-		if (m_pWidget->allocation.width & (s - 1))
-			LineWidth = ((~(s - 1)) & (m_pWidget->allocation.width * 3)) + s;
+		if (m_WindowWidth & (s - 1))
+			LineWidth = ((~(s - 1)) & (m_WindowWidth * 3)) + s;
 		else
-			LineWidth = m_pWidget->allocation.width * 3;
-		unsigned size = LineWidth * m_pWidget->allocation.height;
+			LineWidth = m_WindowWidth * 3;
+		unsigned size = LineWidth * m_WindowHeight;
 		int i, j;
-		hstep = m_pWidget->allocation.width;
-		vstep = m_pWidget->allocation.height;
+		hstep = m_WindowWidth;
+		vstep = m_WindowHeight;
 		tmp = new unsigned char[size];
 		if (!tmp)
 			goto osmesa;
@@ -491,7 +478,7 @@ GdkPixbuf *GLView::BuildPixbuf (unsigned width, unsigned height) const
 					gdk_gl_drawable_gl_end (gldrawable);
 					glPixelStorei (GL_PACK_ALIGNMENT, s);
 					glReadBuffer (GL_BACK_LEFT);
-					glReadPixels (0, 0, m_pWidget->allocation.width, m_pWidget->allocation.height, GL_RGB,
+					glReadPixels (0, 0, m_WindowWidth, m_WindowHeight, GL_RGB,
 										GL_UNSIGNED_BYTE, tmp);
 					// copy the data to the pixbuf.
 					// linesize
@@ -534,8 +521,8 @@ void GLView::DoPrint (G_GNUC_UNUSED GtkPrintOperation *print, GtkPrintContext *c
 	width = gtk_print_context_get_width (context);
 	height = gtk_print_context_get_height (context);
 	int w, h; // size in points
-	w = m_pWidget->allocation.width;
-	h = m_pWidget->allocation.height;
+	w = m_WindowWidth;
+	h = m_WindowHeight;
 	switch (GetScaleType ()) {
 	case GCU_PRINT_SCALE_NONE:
 		break;
