@@ -4,7 +4,7 @@
  * GChemPaint text plugin
  * texttool.cc 
  *
- * Copyright (C) 2002-2009 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -106,7 +106,6 @@ bool gcpTextTool::OnClicked ()
 	if (!m_pObject) {
 		gcp::Text *text = new gcp::Text(m_x0 / pTheme->GetZoomFactor (), m_y0 / pTheme->GetZoomFactor ());
 		m_pView->GetDoc ()->AddObject (text);
-		m_pView->GetDoc ()->AbortOperation ();
 		m_pObject = text;
 		create = true;
 	}
@@ -131,7 +130,7 @@ bool gcpTextTool::OnClicked ()
 		if (m_pView->GetDoc ()->GetCurrentOperation () == NULL && m_Group)
 			m_GroupNode = m_Group->Save (gcp::pXmlDoc);
 	}
-	m_Size = pTheme->GetTextFontSize () / PANGO_SCALE;
+	m_Size = pTheme->GetTextFontSize ();
 	return true;
 }
 
@@ -192,6 +191,8 @@ bool gcpTextTool::OnKeyPress (GdkEventKey* event)
 				return true;
 			case GDK_plus:
 			case GDK_dead_circumflex:
+			case GDK_KP_Add:
+			case GDK_asciicircum:
 				m_Position = (m_Position == gccv::Superscript)? gccv::Normalscript: gccv::Superscript;
 				BuildTagsList ();
 				return true;
@@ -283,11 +284,13 @@ bool gcpTextTool::Unselect ()
 	char const *text = m_Active->GetText ();
 	m_Active = NULL;
 	while (!m_UndoList.empty ()) {
-		xmlFree(m_UndoList.front ());
+		xmlUnlinkNode (m_UndoList.front ());
+		xmlFreeNode (m_UndoList.front ());
 		m_UndoList.pop_front ();
 	}
 	while (!m_RedoList.empty ()) {
-		xmlFree(m_RedoList.front ());
+		xmlUnlinkNode (m_RedoList.front ());
+		xmlFreeNode (m_RedoList.front ());
 		m_RedoList.pop_front ();
 	}
 	xmlBufferPtr initbuf = xmlBufferCreate ();
@@ -298,6 +301,10 @@ bool gcpTextTool::Unselect ()
 	if (strcmp ((char*) initbuf->content, (char*) endbuf->content)) {
 		if (m_Group) {
 			pOp = m_pView->GetDoc ()->GetCurrentOperation ();
+			if (pOp && dynamic_cast <gcp::ModifyOperation *> (pOp) == NULL) {
+				m_pView->GetDoc ()->AbortOperation ();
+				pOp = NULL;
+			}
 			if (!pOp) {
 				pOp = m_pView->GetDoc ()->GetNewOperation (gcp::GCP_MODIFY_OPERATION);
 				pOp->AddNode (m_GroupNode, 0);
@@ -355,10 +362,14 @@ bool gcpTextTool::Unselect ()
 	}
 	xmlBufferFree (initbuf);
 	xmlBufferFree (endbuf);
-	if (m_CurNode)
-		xmlFree (m_CurNode);
-	if (m_InitNode)
-		xmlFree (m_InitNode);
+	if (m_CurNode) {
+ 		xmlUnlinkNode (m_CurNode);
+		xmlFreeNode (m_CurNode);
+	}
+	if (m_InitNode) {
+		xmlUnlinkNode (m_InitNode);
+		xmlFreeNode (m_InitNode);
+	}
 	m_CurNode = m_InitNode = NULL;
 	if (!*text) {
 		Object* pMol = pObj->GetMolecule ();	//if pObj is a fragment
@@ -545,7 +556,10 @@ bool gcpTextTool::OnUndo ()
 		{
 			if (!m_RedoList.empty())
 			{
-				if (m_CurNode) xmlFree(m_CurNode);
+				if (m_CurNode) {
+					xmlUnlinkNode (m_CurNode);
+					xmlFreeNode (m_CurNode);
+				}
 				m_CurNode = m_RedoList.back();
 				m_RedoList.pop_back();
 			}
@@ -589,7 +603,8 @@ void gcpTextTool::PushNode (xmlNodePtr node)
 {
 	gcp::Window *pWin = m_pView->GetDoc ()->GetWindow ();
 	while (!m_RedoList.empty ()) {
-		xmlFree (m_RedoList.front ());
+		xmlUnlinkNode (m_RedoList.front ());
+		xmlFreeNode (m_RedoList.front ());
 		m_RedoList.pop_front ();
 		pWin->ActivateActionWidget ("/MainMenu/EditMenu/Redo", false);
 	}
@@ -618,7 +633,6 @@ void gcpTextTool::OnGetData (GtkClipboard *clipboard, GtkSelectionData *selectio
 		xmlDocDumpFormatMemory (pDoc, &gcp::ClipboardData, &size, info);
 		gtk_selection_data_set (selection_data, gdk_atom_intern (GCHEMPAINT_ATOM_NAME, FALSE), 8,  (const guchar*) gcp::ClipboardData, size);
 	}
-	gcp::cleared = false;
 	if (clipboard == gtk_clipboard_get (GDK_SELECTION_CLIPBOARD))
 			m_pView->GetDoc ()->GetWindow ()->ActivateActionWidget ("/MainMenu/EditMenu/Paste", true);
 }
@@ -687,10 +701,21 @@ void gcpTextTool::UpdateTagsList ()
 				}
 			}
 		}
+	} else {
+		m_FamilyName = pTheme->GetTextFontFamily ();
+		m_Style = pTheme->GetFontStyle ();
+		m_Weight = pTheme->GetFontWeight ();
+		m_Stretch = pTheme->GetFontStretch ();
+		m_Variant = pTheme->GetFontVariant ();
+		m_Size = pTheme->GetTextFontSize ();
+		m_Underline = gccv::TextDecorationNone;
+		m_Rise = 0;
+		m_Color = GO_COLOR_BLACK;
+		m_Position = gccv::Normalscript;
 	}
 	// select the found face
 	GtkTreeIter iter;
-	char const *buf;
+	char *buf;
 	gtk_tree_model_get_iter_first (GTK_TREE_MODEL (m_FamilyList), &iter);
 	do {
 		gtk_tree_model_get (GTK_TREE_MODEL (m_FamilyList), &iter, 0, &buf, -1);
@@ -703,8 +728,10 @@ void gcpTextTool::UpdateTagsList ()
 			g_signal_handler_unblock (m_FaceSel, m_FaceSignal);
 			g_signal_handler_unblock (m_FamilySel, m_FamilySignal);
 			gtk_tree_path_free (path);
+			g_free (buf);
 			break;
 		}
+		g_free (buf);
 	} while (gtk_tree_model_iter_next (GTK_TREE_MODEL (m_FamilyList), &iter));
 	// Update other widgets
 	SetSizeFull (true, false);
@@ -855,14 +882,19 @@ GtkWidget *gcpTextTool::GetPropertyPage ()
 	string name;
 	bool default_found = false;
 	for (i = 0; i < nb; i++) {
-		PangoFontFace **faces;
-		int *sizes, n;
+		PangoFontFace **faces = NULL;
+		int *sizes = NULL, n;
 		pango_font_family_list_faces (families[i], &faces, &n);
-		if (n <= 0)
+		if (n <= 0) {
+			g_free (faces);
 			continue;
+		}
 		pango_font_face_list_sizes (faces[0], &sizes, &n);
-		if (n > 0) // Do not use bitmap fonts
+		if (n > 0) {// Do not use bitmap fonts
+			g_free (faces);
+			g_free (sizes);
 			continue;
+		}
 		name = pango_font_family_get_name (families[i]);
 		m_Families[name] = (PangoFontFamily*) g_object_ref (families[i]);
 		gtk_list_store_append (m_FamilyList, &iter);
@@ -873,7 +905,10 @@ GtkWidget *gcpTextTool::GetPropertyPage ()
 			selected = iter;
 			default_found = true;
 		}
+		g_free (faces);
+		g_free (sizes);
 	}
+	g_free (families);
 	if (!default_found) {
 		if	(!gtk_tree_model_get_iter_first (GTK_TREE_MODEL (m_FamilyList), &iter))
 			return NULL;
@@ -916,9 +951,10 @@ void gcpTextTool::OnSelectFamily (GtkTreeSelection *selection)
 		return;
 	gtk_tree_model_get (model, &iter, 0, &name, -1);
 	m_FamilyName = name;
+	g_free (const_cast <char *> (name));
 	PangoFontFamily *family = m_Families[m_FamilyName];
 	PangoFontFace **faces;
-	int i, besti, nb;
+	int i, nb;
 	g_signal_handler_block (m_FaceSel, m_FaceSignal);
 	pango_font_family_list_faces (family, &faces, &nb);
 	gtk_list_store_clear (m_FaceList);
@@ -954,11 +990,11 @@ void gcpTextTool::OnSelectFamily (GtkTreeSelection *selection)
 		if (distance < best) {
 			best = distance;
 			selected = iter;
-			besti = i;
 		}
 		// TODO: write this code
 		pango_font_description_free (desc);
 	}
+	g_free (faces);
 	g_signal_handler_unblock (m_FaceSel, m_FaceSignal);
 	GtkTreePath *path = gtk_tree_model_get_path (GTK_TREE_MODEL (m_FaceList), &selected);
 	if (path) {
@@ -982,11 +1018,12 @@ void gcpTextTool::OnSelectFace (GtkTreeSelection *selection)
 {
 	GtkTreeModel *model;
 	GtkTreeIter iter;
-	char const *name;
+	char *name;
 	if (!gtk_tree_selection_get_selected (selection, &model, &iter))
 		return;
 	gtk_tree_model_get (model, &iter, 0, &name, -1);
 	PangoFontFace *face = m_Faces[name];
+	g_free (name);
 	PangoFontDescription *desc = pango_font_face_describe (face);
 	m_Style = pango_font_description_get_style (desc);
 	m_Weight = pango_font_description_get_weight (desc);
