@@ -27,7 +27,7 @@
 #include "application.h"
 #include "view.h"
 #include "window.h"
-#include <glib/gutils.h>
+#include <glib.h>
 
 gc3dDocument::gc3dDocument (gc3dApplication *App): Chem3dDoc (App, new gc3dView (this))
 {
@@ -40,10 +40,14 @@ gc3dDocument::~gc3dDocument ()
 void gc3dDocument::Load (char const *uri, char const *mime_type)
 {
 	Chem3dDoc::Load (uri, mime_type);
-	char *title = g_strdup (GetTitle ());
-	if (!title || !*title)
+	char *title = g_strdup (GetTitle ().c_str ());
+	if (!*title)
 		title = g_path_get_basename (uri);
-	dynamic_cast <gc3dView *> (m_View)->GetWindow ()->SetTitle (title);
+	char *buf = g_uri_unescape_string (title, NULL);
+	dynamic_cast <gc3dView *> (m_View)->GetWindow ()->SetTitle (buf);
+	g_free (buf);
 	g_free (title);
-	
+	char *dirname = g_path_get_dirname (uri);
+	m_App->SetCurDir (dirname);
+	g_free (dirname);
 }
