@@ -28,8 +28,6 @@
 #include "view.h"
 #include "window.h"
 #include <gcu/filechooser.h>
-#include <goffice/utils/go-image.h>
-#include <gio/gio.h>
 #include <glib/gi18n.h>
 #include <clocale>
 #include <map>
@@ -70,7 +68,7 @@ void gsvApplication::OnQuit ()
 	}
 }
 
-bool gsvApplication::FileProcess (const gchar* filename, const gchar* mime_type, bool bSave, GtkWindow *window, Document *Doc)
+bool gsvApplication::FileProcess (const gchar* filename, const gchar* mime_type, bool bSave, G_GNUC_UNUSED GtkWindow *window, Document *Doc)
 {
 	gsvDocument *pDoc = dynamic_cast <gsvDocument *> (Doc);
 	if(bSave) {
@@ -120,7 +118,6 @@ void gsvApplication::OnSaveAsImage (gsvDocument *Doc)
 	if (!Doc)
 		return;
 	list<string> l;
-	unsigned n = 0;
 	char const *mime;
 	map<string, GdkPixbufFormat*>::iterator i, end = m_SupportedPixbufFormats.end ();
 	for (i = m_SupportedPixbufFormats.begin (); i != end; i++)
