@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * programs/spectra/gspectrum.cc
  *
- * Copyright (C) 2007-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2007-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -56,6 +56,7 @@ int main (int argc, char *argv[])
 	gsvDocument *pDoc = App->OnFileNew();
 	char *path, *uri;
 	bool bres = false;
+	argv++;
 	while (*argv) {
 		if (**argv == '-') {
 			printf (_("Invalid or misplaced argument: %s\n"), *argv);
@@ -65,13 +66,21 @@ int main (int argc, char *argv[])
 		if (strstr (*argv, "://"))
 			uri = g_strdup (*argv);
 		else {
-			path = g_path_is_absolute (*argv)? g_strdup (*argv): g_build_filename (g_get_current_dir (), *argv, NULL);
+			if (g_path_is_absolute (*argv))
+				path = g_strdup (*argv);
+			else {
+				char *dir = g_get_current_dir ();
+				path = g_build_filename (dir, *argv, NULL);
+				g_free (dir);
+			}
 			uri = g_filename_to_uri (path, NULL, NULL);
 			g_free (path);
 		}
 		if (bres)
 			pDoc = App->OnFileNew ();
-		bres = App->FileProcess (uri, go_get_mime_type (uri), false, NULL, pDoc);
+		char *mime_type = go_get_mime_type (uri);
+		bres = App->FileProcess (uri, mime_type, false, NULL, pDoc);
+		g_free (mime_type);
 		g_free (uri);
 		argv++;
 	}
